summaryrefslogtreecommitdiff
path: root/bfd/elf32-score.c
diff options
context:
space:
mode:
Diffstat (limited to 'bfd/elf32-score.c')
-rw-r--r--bfd/elf32-score.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/bfd/elf32-score.c b/bfd/elf32-score.c
index f1f1aae1e7..fec177af07 100644
--- a/bfd/elf32-score.c
+++ b/bfd/elf32-score.c
@@ -2126,7 +2126,7 @@ score_elf_final_link_relocate (reloc_howto_type *howto,
&& h != NULL
&& h->root.def_dynamic
&& !h->root.def_regular))
- && r_symndx != 0
+ && r_symndx != STN_UNDEF
&& (input_section->flags & SEC_ALLOC) != 0)
{
/* If we're creating a shared library, or this relocation is against a symbol
@@ -2139,8 +2139,8 @@ score_elf_final_link_relocate (reloc_howto_type *howto,
input_section))
return bfd_reloc_undefined;
}
- else if (r_symndx == 0)
- /* r_symndx will be zero only for relocs against symbols
+ else if (r_symndx == STN_UNDEF)
+ /* r_symndx will be STN_UNDEF (zero) only for relocs against symbols
from removed linkonce sections, or sections discarded by
a linker script. */
value = 0;